# Documentation Issue Hub

Each subproject has its own documentation. This page provides quick links
to documentation issues for Jupyter subprojects.

## Docs Issues Per-Subproject

- [Jupyter.org (meta-project) issues](https://github.com/jupyter/jupyter/labels/documentation) (`documentation` label)
- [Jupyter Notebook issues](https://github.com/jupyter/notebook/labels/documentation) (`documentation` label)
- [JupyterLab issues](https://github.com/jupyterlab/jupyterlab/labels/documentation) (`documentation` label)
- [Jupyter Server issues](https://github.com/jupyter-server/jupyter_server/labels/documentation) (`documentation` label)
- [JupyterHub issues](https://github.com/jupyterhub/jupyterhub/labels/documentation) (`documentation` label)
- [ipywidgets issues](https://github.com/jupyter-widgets/ipywidgets/labels/documentation) (`documentation` label)
